@@ -1,14 +1,12 @@
 static char *TEAM_LIST[] = {
 "Holger Berndt <berndth@users.sf.net>",
+"Jonathan Boeing <jonathan@claws-mail.org>",
 "Tristan Chabredier <wwp@claws-mail.org>",
-"Andrej Kacian <andrej@kacian.sk>",
 "Darko Koruga <darko@users.sf.net>",
-"Charles Lehner <charles@claws-mail.org>",
-"Colin Leroy-Mira <colin@colino.net>",
+"Thorsten Maerz <thorsten@claws-mail.org>",
 "Paul Mangan <paul@claws-mail.org>",
 "Ricardo Mones Lastra <ricardo@mones.org>",
 "Salvatore De Paolis <iwkse@claws-mail.org>",
-"Paweł Pękala <c0rn@o2.pl>",
 "Michael Rasmussen <mir@datanom.net>",
 NULL
 };
@@ -21,8 +19,11 @@ static char *EX_TEAM_LIST[] = {
 "Oliver Haertel",
 "Christoph Hohmann",
 "Alfons Hoogervorst",
+"Andrej Kacian",
 "Werner Koch",
-"Thorsten Maerz",
+"Charles Lehner",
+"Colin Leroy-Mira",
+"Paweł Pękala",
 "Leandro A. F. Pereira",
 "Luke Plant",
 "Martin Schaaf",
@@ -48,7 +49,7 @@ static char *TRANS_TEAM_LIST[] = {
 "[ja] UTUMI Hirosi <utuhiro78@yahoo.co.jp>",
 "[nb] Petter Adsen <petter@synth.no>",
 "[nl] Marcel Pol <mpol@gmx.net>",
-"[pl] Jakub Jankiewicz <jcubic@jcubic.pl>",
+"[pl] Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>",
 "[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
 "[pt_PT] Pedro Albuquerque <palbuquerque73@gmail.com>",
 "[ro] Cristian Secară <liste@secarica.ro>",
@@ -63,12 +64,10 @@ NULL
 static char *DOC_TEAM_LIST[] = {
 "[en] Tristan Chabredier <wwp@claws-mail.org>",
 "     Ricardo Mones Lastra <ricardo@mones.org>",
-"     Colin Leroy <colin@colino.net>",
 "     Paul Mangan <paul@claws-mail.org>",
+"[de] Christoph Klassen <christoph.klassen@intevation.de>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
 "[fr] Tristan Chabredier <wwp@claws-mail.org>",
-"     Colin Leroy <colin@colino.net>",
-"[pl] Paweł Pękala <c0rn@gazeta.pl>",
 NULL
 };
 
@@ -127,6 +126,7 @@ static char *CONTRIBS_LIST[] = {
 "Ben Deering",
 "Jean Delvare",
 "Pierric Descamps",
+"Orivej Desh",
 "Rodrigo Dias Arruda Senra",
 "Frank Dietrich",
 "Tim Dijkstra",
@@ -142,6 +142,7 @@ static char *CONTRIBS_LIST[] = {
 "Tiago Faria",
 "Alessandro Di Federico",
 "Lars Persson Fink",
+"David Fletcher",
 "Bob Forsman",
 "Matthias Förste",
 "Ivan Francolin Martinez",
@@ -224,10 +225,12 @@ static char *CONTRIBS_LIST[] = {
 "Bram Metsch",
 "Hanno Meyer-Thurow",
 "George Michaelson",
+"Raphael Michel",
 "Florian Mickler",
 "Neill Miller",
 "Suzuki Mio",
 "Alex S Moore",
+"Frank Mueller",
 "NAKAGAWA",
 "Yuuki NINOMIYA",
 "Satoshi Nagayasu",
@@ -253,12 +256,14 @@ static char *CONTRIBS_LIST[] = {
 "Thomas Orgis",
 "Reza Pakdel",
 "Richard Palo",
+"Alvar Penning",
 "Damian Poddebniak",
 "Marcel Pol",
 "Martin Pool",
 "Quar",
 "Don Quijote",
 "Steve Rader",
+"Steve Randall",
 "Jens Rantil",
 "Ravemax",
 "Eric S. Raymond",
@@ -291,6 +296,7 @@ static char *CONTRIBS_LIST[] = {
 "Dale P. Smith",
 "Avinash Sonawane",
 "Andrea Spadaccini",
+"Manuel Stoeckl",
 "Bogdan Sumanariu",
 "TAKANO",
 "TOGAWA",
@@ -305,6 +311,7 @@ static char *CONTRIBS_LIST[] = {
 "Masahiro Tomita",
 "Tomita",
 "Topia",
+"Ramin Yaghoubzadeh Torky",
 "Anders Troback",
 "Tsutsui",
 "Aleksandar Urošević",
